### Pacifica Policy version
[Version of the pacifica software where you are encountering the issue]

### Pacifica Core Software versions
[Versions of the pacifica core software components related to this issue]

### Platform Details
[Operating system distribution and release version. Cloud provider if running in the cloud]

### Scenario:
[What you are trying to achieve and you can't?]

### Steps to Reproduce:
[If you are filing an issue what are the things we need to do in order to reproduce your problem? How are you using this software or any resources it includes?]

### Expected Result:
[What are you expecting to happen as the consequence of above reproduction steps?]

### Actual Result:
[What actually happens after the reproduction steps? Include the error output or a link to a gist if possible.]
